==> orchestra-pvm-4.2.1-sources.jar: org/ow2/orchestra/pvm/internal/svc/AsyncCommandMessage.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.svc;

import org.ow2.orchestra.pvm.env.Environment;
import org.ow2.orchestra.pvm.internal.cmd.Command;
import org.ow2.orchestra.pvm.internal.cmd.CommandService;
import org.ow2.orchestra.pvm.internal.job.MessageImpl;

/**
 * @author Tom Baeyens
 */
public class AsyncCommandMessage extends MessageImpl<Object> {

  private static final long serialVersionUID = 1L;

  protected final Command< ? > command;
  protected String userId;

  public AsyncCommandMessage(final Command< ? > command) {
    this.command = command;
  }

  public AsyncCommandMessage(final Command< ? > command, final String userId) {
    this.command = command;
    this.userId = userId;
  }

  public Object execute(final Environment environment) throws Exception {
    this.unlockExecution();
    if (this.userId != null) {
      environment.setUserId(this.userId);
    }
    try {
      final CommandService commandService = environment.get(CommandService.class);
      commandService.execute(this.command);
    } finally {
      if (this.userId != null) {
        environment.setUserId(null);
      }
    }
    return null;
  }

  @Override
  public String toString() {
    return "async-command-message[" + this.dbid + "]";
  }
}

==> orchestra-pvm-4.6.2-sources.jar: org/ow2/orchestra/pvm/internal/svc/AsyncCommandMessage.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.svc;

import org.ow2.orchestra.pvm.env.Environment;
import org.ow2.orchestra.pvm.internal.cmd.Command;
import org.ow2.orchestra.pvm.internal.cmd.CommandService;
import org.ow2.orchestra.pvm.internal.job.MessageImpl;

/**
 * @author Tom Baeyens
 */
public class AsyncCommandMessage extends MessageImpl<Object> {

  private static final long serialVersionUID = 1L;

  protected final Command< ? > command;
  protected String userId;

  public AsyncCommandMessage(final Command< ? > command) {
    this.command = command;
  }

  public AsyncCommandMessage(final Command< ? > command, final String userId) {
    this.command = command;
    this.userId = userId;
  }

  public Object execute(final Environment environment) {
    this.unlockExecution();
    if (this.userId != null) {
      environment.setUserId(this.userId);
    }
    try {
      final CommandService commandService = environment.get(CommandService.class);
      commandService.execute(this.command);
    } finally {
      if (this.userId != null) {
        environment.setUserId(null);
      }
    }
    return null;
  }

  @Override
  public String toString() {
    return "async-command-message[" + this.dbid + "]";
  }
}
